.. image:: doc/_static/strawberry-fields-text.png
    :alt: Strawberry Fields

##################################################

.. image:: https://img.shields.io/travis/XanaduAI/strawberryfields/master.svg?style=popout-square
    :alt: Travis
    :target: https://travis-ci.org/XanaduAI/strawberryfields

.. image:: https://img.shields.io/codecov/c/github/xanaduai/strawberryfields/master.svg?style=popout-square
    :alt: Codecov coverage
    :target: https://codecov.io/gh/XanaduAI/strawberryfields

.. image:: https://img.shields.io/codefactor/grade/github/XanaduAI/strawberryfields/master?style=flat-square
    :alt: CodeFactor Grade
    :target: https://www.codefactor.io/repository/github/xanaduai/strawberryfields

.. image:: https://img.shields.io/readthedocs/strawberryfields.svg?style=popout-square
    :alt: Read the Docs
    :target: https://strawberryfields.readthedocs.io

.. image:: https://img.shields.io/pypi/v/StrawberryFields.svg?style=popout-square
    :alt: PyPI
    :target: https://pypi.org/project/StrawberryFields

.. image:: https://img.shields.io/pypi/pyversions/StrawberryFields.svg?style=popout-square
    :alt: PyPI - Python Version
    :target: https://pypi.org/project/StrawberryFields

`Strawberry Fields <https://strawberryfields.readthedocs.io>`_ is a full-stack Python library for designing,
simulating, and optimizing continuous-variable quantum
optical circuits.


Features
========

* Execute photonic quantum algorithms directly on `Xanadu's next-generation quantum hardware
  <https://strawberryfields.ai/photonics/hardware/index.html>`__

* `High-level functions <https://strawberryfields.ai/photonics/applications.html>`__ for **solving
  practical problems** including **graph and network optimization**, **machine learning**, and
  **chemistry**

* Includes a suite of world-class simulators—based on cutting-edge algorithms—to compile and
  simulate photonic algorithms

* `Train and optimize
  <https://strawberryfields.ai/photonics/demonstrations.html#optimization-and-machine-learning>`__
  your quantum programs with our end-to-end differentiable TensorFlow backend

* Powers the `Strawberry Fields Interactive <https://strawberryfields.ai>`_ web app, which allows
  anyone to run a quantum computing simulation via **drag and drop**


Installation
============

Strawberry Fields requires Python version 3.6, 3.7, or 3.8. Installation of Strawberry Fields, as well as all dependencies, can be done using pip:

.. code-block:: bash

    pip install strawberryfields


Getting started
===============

To see Strawberry Fields in action immediately, try out our `Strawberry Fields Interactive
<https://strawberryfields.ai>`_ web application. Prepare your initial states, drag and drop gates,
and watch your simulation run in real time right in your web browser.

To get started with writing your own Strawberry Fields code, begin with our `photonic circuit
quickstart guides
<https://strawberryfields.readthedocs.io/en/stable/introduction/introduction.html>`__, before
exploring our many `tutorials <https://strawberryfields.ai/photonics/demonstrations.html>`__ and
`applications <https://strawberryfields.ai/photonics/applications.html>`__.

Finally, read more about using Strawberry Fields with `photonic hardware
<https://strawberryfields.ai/photonics/hardware/index.html>`__, including code demonstrations
and an overview of Xanadu's quantum photonic hardware.

Developers can head to the `development guide
<https://strawberryfields.readthedocs.io/en/stable/development/development_guide.html>`_ to see how
they can contribute to Strawberry Fields.

Contributing to Strawberry Fields
=================================

We welcome contributions—simply fork the Strawberry Fields repository, and then make a
`pull request <https://help.github.com/articles/about-pull-requests/>`_ containing your contribution.  All contributors to Strawberry Fields will be listed as authors on the releases.

We also encourage bug reports, suggestions for new features and enhancements, and even links to cool projects or applications built on Strawberry Fields.

See our `contributions page <https://github.com/XanaduAI/strawberryfields/blob/master/.github/CONTRIBUTING.md>`_
for more details, and then check out some of the Strawberry Fields `challenges <https://github.com/XanaduAI/strawberryfields/blob/master/.github/CHALLENGES.md>`_ for some inspiration.

Authors
=======

Strawberry Fields is the work of `many contributors <https://github.com/XanaduAI/strawberryfields/graphs/contributors>`_.

If you are doing research using Strawberry Fields, please cite our papers:

  Nathan Killoran, Josh Izaac, Nicolás Quesada, Ville Bergholm, Matthew Amy, and Christian Weedbrook. "Strawberry Fields: A Software Platform for Photonic Quantum Computing", `Quantum, 3, 129 <https://quantum-journal.org/papers/q-2019-03-11-129/>`__ (2019).

  Thomas R. Bromley, Juan Miguel Arrazola, Soran Jahangiri, Josh Izaac, Nicolás Quesada, Alain Delgado Gran, Maria Schuld, Jeremy Swinarton, Zeid Zabaneh, and Nathan Killoran. "Applications of Near-Term Photonic Quantum Computers: Software and Algorithms", `Quantum Sci. Technol. 5 034010 <https://iopscience.iop.org/article/10.1088/2058-9565/ab8504/meta>`__ (2020).

Support
=======

- **Source Code:** https://github.com/XanaduAI/strawberryfields
- **Issue Tracker:** https://github.com/XanaduAI/strawberryfields/issues

If you are having issues, please let us know by posting the issue on our Github issue tracker.

We also have a `Slack channel <https://u.strawberryfields.ai/slack>`_ and a `discussion forum <https://discuss.pennylane.ai>`_ -
come join the discussion and chat with our Strawberry Fields team.


License
=======

Strawberry Fields is **free** and **open source**, released under the Apache License, Version 2.0.
